radish
======

    ``radish`` is a "Behavior-Driven Developement"-Tool written in
    python Version: 0.01.06


--------------

**Author:** Timo Furrer tuxtimo@gmail.com **License:** GPL
**Version:** 0.01.06

What is ``radish`` ?
--------------------

``radish`` is a "Behavior-Driven Developement"-Tool written in
python. It is inspired by other ``BDD``-Tools like ``lettuce`` and
``cucumber``. The feature, step and terrain files are all
compatible with ``lettuce``.

How to install?
---------------

Simply use pip:

::

    pip install radish

To install it on your system you can use the ``setup.py`` script:

::

    python setup.py install

*Note: You need root access for the above command*

You can now start it with:

::

    radish [arguments]

How to use?
-----------

Coming soon ...

Writing tests
-------------

Coming soon ...

Contributing
------------

Coming soon ...

Infos
-----

The files which are currently in the testfiles-folder are from
lettuce - another TDD tool!


